@@ -1,24 +1,5 @@
 #! /usr/bin/env python3
 
-# dbnomics-fetcher-ops -- Manage DBnomics fetchers
-# By: Christophe Benz <christophe.benz@cepremap.org>
-#
-# Copyright (C) 2020 Cepremap
-# https://git.nomics.world/dbnomics/dbnomics-fetcher-ops
-#
-# dbnomics-fetcher-ops is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# dbnomics-fetcher-ops is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """CLI to manage DBnomics fetchers."""
 
 
@@ -31,6 +12,7 @@ from xdg import xdg_config_home
 
 from . import app_args, loaders
 from .commands.apply import apply_command
+from .commands.clean_workspaces import clean_workspaces_command
 from .commands.configure import configure_command
 from .commands.list import list_command
 from .commands.run import run_command
@@ -45,6 +27,7 @@ logger = daiquiri.getLogger(__name__)
 
 app = typer.Typer()
 app.command(name="apply")(apply_command)
+app.command(name="clean-workspaces")(clean_workspaces_command)
 app.command(name="configure")(configure_command)
 app.command(name="list")(list_command)
 app.command(name="run")(run_command)
@@ -53,7 +36,6 @@ app.command(name="undeploy")(undeploy_command)
 
 @app.callback(context_settings={"help_option_names": ["-h", "--help"]})
 def callback(
-    ctx: typer.Context,
     debug: bool = typer.Option(False, "-d", "--debug", envvar="DEBUG", help="Display DEBUG log messages"),
     dry_run: bool = typer.Option(False, "-n", "--dry-run", envvar="DRY_RUN", help="Do not execute actions for real"),
     verbose: bool = typer.Option(False, "-v", "--verbose", envvar="VERBOSE", help="Display INFO log messages"),
