@@ -1,22 +1,3 @@
-# dbnomics-fetcher-ops -- Manage DBnomics fetchers
-# By: Christophe Benz <christophe.benz@cepremap.org>
-#
-# Copyright (C) 2020 Cepremap
-# https://git.nomics.world/dbnomics/dbnomics-fetcher-ops
-#
-# dbnomics-fetcher-ops is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# dbnomics-fetcher-ops is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 from dataclasses import dataclass
 from functools import partial
 from typing import Dict, List, Literal, Optional, Tuple, Union
@@ -126,6 +107,10 @@ class ProjectRef(BaseModel):
         """Return a tuple with the group name and project name resolved with the given provider slug."""
         return self.expand(self.group, provider_slug), self.expand(self.name, provider_slug)
 
+    def get_path_with_namespace(self, provider_slug: str) -> str:
+        namespace_path, project_path = self.expand_group_and_name(provider_slug)
+        return f"{namespace_path}/{project_path}"
+
 
 class GitLabStructure(BaseModel):
     base_url: HttpUrl
@@ -138,8 +123,8 @@ class GitLabStructure(BaseModel):
         return v.rstrip("/")
 
     def get_http_clone_url(self, provider_slug: str, *, project_ref: ProjectRef) -> str:
-        group, name = project_ref.expand_group_and_name(provider_slug)
-        return f"{self.base_url}/{group}/{name}.git"
+        path_with_namespace = project_ref.get_path_with_namespace(provider_slug)
+        return f"{self.base_url}/{path_with_namespace}.git"
 
 
 class FetcherMetadata(BaseModel):
