@@ -31,8 +31,7 @@ def run_fetcher_pipeline(
     gl = init_gitlab_client(gitlab_url, enable_debug=debug_gitlab, private_token=gitlab_private_token)
 
     project_ref = fetcher_metadata.gitlab.fetcher
-    fetcher_group_name, fetcher_project_name = project_ref.expand_group_and_name(provider_slug)
-    project_path_with_namespace = f"{fetcher_group_name}/{fetcher_project_name}"
+    project_path_with_namespace = project_ref.get_path_with_namespace(provider_slug)
 
     fetcher_project = gl.projects.get(project_path_with_namespace)
 
